@@ -6,7 +6,10 @@ use warnings;
 use Moo;
 use strictures 2;
 use namespace::clean;
-use Types::Standard qw(Bool Str Num Int Map ArrayRef HashRef);
+
+extends 'OpenAI::API::Request';
+
+use Types::Standard qw(Any Bool Int Num Str Map ArrayRef HashRef);
 
 has model    => ( is => 'rw', isa => Str, required => 1, default => 'gpt-3.5-turbo' );
 has messages => ( is => 'rw', isa => ArrayRef[HashRef], required => 1, );
@@ -18,13 +21,14 @@ has n                 => ( is => 'rw', isa => Int, );
 has stream            => ( is => 'rw', isa => Bool, );
 has logprobs          => ( is => 'rw', isa => Int, );
 has echo              => ( is => 'rw', isa => Bool, );
-has stop              => ( is => 'rw', isa => Str, );
+has stop              => ( is => 'rw', isa => Any, );
 has presence_penalty  => ( is => 'rw', isa => Num, );
 has frequency_penalty => ( is => 'rw', isa => Num, );
 has logit_bias        => ( is => 'rw', isa => Map [ Int, Int ], );
 has user              => ( is => 'rw', isa => Str, );
 
 sub endpoint { 'chat/completions' }
+sub method   { 'POST' }
 
 1;
 
@@ -34,9 +38,26 @@ __END__
 
 OpenAI::API::Request::Chat - chat endpoint
 
+=head1 SYNOPSIS
+
+    use OpenAI::API::Request::Chat;
+
+    my $request = OpenAI::API::Request::Chat->new(
+        model    => "gpt-3.5-turbo",
+        messages => [
+            { "role" => "system",    "content" => "You are a helpful assistant." },
+            { "role" => "user",      "content" => "Who won the world series in 2020?" },
+            { "role" => "assistant", "content" => "The Los Angeles Dodgers won the World Series in 2020." },
+            { "role" => "user",      "content" => "Where was it played?" }
+        ],
+    );
+
+    my $res = $request->send();
+
 =head1 DESCRIPTION
 
-Given a chat conversation, the model will return a chat completion response.
+Given a chat conversation, the model will return a chat completion
+response (similar to ChatGPT).
 
 =head1 METHODS
 
@@ -53,7 +74,8 @@ for a reference of them.
 
 =item * messages
 
-The messages to generate chat completions for, in the chat format.
+The messages to generate chat completions for, in the L<chat
+format|https://platform.openai.com/docs/guides/chat/introduction>.
 
 =item * max_tokens [optional]
 
