@@ -6,6 +6,9 @@ use warnings;
 use Moo;
 use strictures 2;
 use namespace::clean;
+
+extends 'OpenAI::API::Request';
+
 use Types::Standard qw(Bool Str Num Int Map);
 
 has model       => ( is => 'rw', isa => Str, required => 1, );
@@ -17,6 +20,7 @@ has top_p       => ( is => 'rw', isa => Num, );
 has n           => ( is => 'rw', isa => Int, );
 
 sub endpoint { 'edits' }
+sub method   { 'POST' }
 
 1;
 
@@ -26,6 +30,18 @@ __END__
 
 OpenAI::API::Request::Edit - edits endpoint
 
+=head1 SYNOPSIS
+
+    use OpenAI::API::Request::Edit;
+
+    my $request = OpenAI::API::Request::Edit->new(
+        model       => "text-davinci-edit-001",
+        input       => "What day of the wek is it?",
+        instruction => "Fix the spelling mistakes",
+    );
+
+    my $res = $request->send();
+
 =head1 DESCRIPTION
 
 Creates a new edit for the provided input, instruction, and parameters.
