@@ -6,6 +6,9 @@ use warnings;
 use Moo;
 use strictures 2;
 use namespace::clean;
+
+extends 'OpenAI::API::Request';
+
 use Types::Standard qw(Bool Str Num Int Map);
 
 has model => ( is => 'rw', isa => Str, required => 1, );
@@ -14,6 +17,7 @@ has input => ( is => 'rw', isa => Str, required => 1, );
 has user => ( is => 'rw', isa => Str, );
 
 sub endpoint { 'embeddings' }
+sub method   { 'POST' }
 
 1;
 
@@ -23,6 +27,17 @@ __END__
 
 OpenAI::API::Request::Embedding - embeddings endpoint
 
+=head1 SYNOPSIS
+
+    use OpenAI::API::Request::Embedding;
+
+    my $request = OpenAI::API::Request::Embedding->new(
+        model => "text-embedding-ada-002",
+        input => "The food was delicious and the waiter...",
+    );
+
+    my $res = $request->send();
+
 =head1 DESCRIPTION
 
 Get a vector representation of a given input that can be easily consumed
